<template>
  <div class="marquee-container" :style="containerStyle">
    <!-- 走马灯内容区域 -->
    <transition name="width-slide">
      <div class="marquee-wrapper" 
           :class="{ 'highlight-mode': highlightMode }"
           ref="marqueeWrapper">
        <marquee 
          :stringArray="displayItems" 
          v-show="!isCollapsed" 
          :style="marqueeStyle"
          >
        </marquee>
        <!-- 高亮模式开关 - 移动到内容区域右侧 -->
        <div class="highlight-switch" @click.stop="toggleHighlight" v-show="!isCollapsed" >
          <img :src="highlightIcon" alt="" />
          <!-- <i class="el-icon-brightness" :class="{ 'active': highlightMode }"></i> -->
        </div>
        <div class="toggle-button" 
            @click="toggleCollapse">
          <i :class="collapseIcon"></i>
        </div>
      </div>
    </transition>
    
    <!-- 展开/收起按钮 -->
    
  </div>
</template>

<script>
import { getAllMessages } from "@/api/message-bar";
import marquee from "@/components/scrollPlayBar/marquee.vue";
export default {
  name: 'MarqueeWithFollowingButton',
  props: {
    defaultCollapsed: {
      type: Boolean,
      default: false
    },
    speed: {
      type: Number,
      default: 50
    }
  },
  components: {
    marquee
  },

  data() {
    return {
      isCollapsed: false,
      highlightMode: false,
      displayItems: [{item_title: '暂无数据', item_value: 'None'}],
    }
  },
  computed: {
    collapseIcon() {
      return this.isCollapsed ? 'el-icon-arrow-right' : 'el-icon-arrow-left'
    },
    highlightIcon() {
      return this.highlightMode ? require('@/assets/images/highlight/kai.png') : require('@/assets/images/highlight/guang.png')
    },
    marqueeStyle() {
      return this.highlightMode ? { 'color': '#296ff0', 'font-weight': 'bold', 'font-size': '28px' } : {}
    },
    containerStyle() {
      return this.isCollapsed ? {'width': '2%'} : {'width': '50%'}
    }
  },
  watch: {
    defaultCollapsed: {
      immediate: true,
      handler(val) {
        this.isCollapsed = val
      }
    }
  },
  created() {
    this.init();
  },
  methods: {
    async init() {
      this.displayItems = (await getAllMessages({})).sort((a, b) => a.item_no - b.item_no)
    },
    toggleCollapse() {
      this.isCollapsed = !this.isCollapsed
      this.highlightMode = false
    },
    toggleHighlight() {
      this.highlightMode = !this.highlightMode
    }
  }
}
</script>

<style scoped lang="scss">
.marquee-container {
  position: absolute;
  bottom: 50px;
  left: 35px;
  height: 60px;
  overflow: hidden;
  transition: width 0.5s ease;
  z-index: 100;
  background-color: rgba(255, 255, 255, 0.8);
  border-radius: 4px;
  box-shadow: 0 2px 12px rgba(0, 0, 0, 0.1);
}

.toggle-button {
  /* position: relative; */
  width: 40px;
  height: 100%;
  display: flex;
  align-items: center;
  justify-content: center;
  cursor: pointer;
  background-color: #0758ec;
  color: white;
  transition: all 0.3s ease;
}

// .toggle-button:hover {
//   background-color: #0758ec;
// }

.toggle-button i {
  margin-right: 6px;
  transition: all 0.3s ease;
}
.marquee-wrapper {
  height: 100%;
  display: flex;
  align-items: center;
  position: relative;
}

.marquee-wrapper.highlight-mode {
  background-color: #ffffff;
  /* border: 1px solid #409eff; */
}

.marquee-content {
  display: flex;
  white-space: nowrap;
  transition: transform 0.1s linear;
  padding: 0 15px;
}

.marquee-item {
  display: inline-flex;
  align-items: center;
  padding: 0 20px;
  font-size: 16px;
  flex-shrink: 0;
}

.item-label {
  color: #606266;
  margin-right: 8px;
  //font-weight: bold;
}

.highlight-mode .item-label {
  color: #296ff0;
  font-weight: bold;
  font-size: 18px;
}

.item-value {
  color: #303133;
  // font-weight: bold;
}

.highlight-mode .item-value {
  color: #296ff0;
  font-weight: bold;
  font-size: 18px;
}

.highlight-switch {
  width: 60px;
  height: 100%;
  display: flex;
  align-items: center;
  justify-content: center;
  cursor: pointer;
  transition: all 0.3s ease;
  img {
      width: 28px;
      height: 28px;
      cursor: pointer;
      margin-right: 10px;
    }
  img :hover {
    transform: scale(1.1);
  }
}

.highlight-switch i {
  font-size: 16px;
  color: #909399;
  transition: all 0.3s ease;
}

.highlight-switch i.active {
  color: #409eff;
}

/* 宽度变化动画 */
.width-slide-enter-active, .width-slide-leave-active {
  transition: all 0.5s ease;
}

.width-slide-enter, .width-slide-leave-to {
  opacity: 0;
  transform: scaleX(0);
  transform-origin: left center;
}
</style>